@@ -5,7 +5,6 @@
 //!
 use std::borrow::Cow;
 
-use polars_arrow::array::PolarsArray;
 use polars_arrow::compute::take::*;
 pub use take_random::*;
 pub use traits::*;
@@ -75,9 +74,9 @@ where
                 if array.null_count() == array.len() {
                     return Self::full_null(self.name(), array.len());
                 }
-                let array = match (self.has_validity(), self.chunks.len()) {
-                    (false, 1) => {
-                        take_no_null_primitive::<T::Native>(chunks.next().unwrap(), array)
+                let array = match (self.null_count(), self.chunks.len()) {
+                    (0, 1) => {
+                        take_no_null_primitive_unchecked::<T::Native>(chunks.next().unwrap(), array)
                             as ArrayRef
                     }
                     (_, 1) => take_primitive_unchecked::<T::Native>(chunks.next().unwrap(), array)
