@@ -1,4 +1,4 @@
-use std::fmt::Debug;
+use std::fmt::{Debug, Display, Formatter};
 use std::hash::Hash;
 
 use ahash::{CallHasher, RandomState};
@@ -911,6 +911,29 @@ pub enum GroupByMethod {
     Var(u8),
 }
 
+impl Display for GroupByMethod {
+    fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
+        use GroupByMethod::*;
+        let s = match self {
+            Min => "min",
+            Max => "max",
+            Median => "median",
+            Mean => "mean",
+            First => "first",
+            Last => "last",
+            Sum => "sum",
+            Groups => "groups",
+            NUnique => "n_unique",
+            Quantile(_, _) => "quantile",
+            Count => "count",
+            List => "list",
+            Std(_) => "std",
+            Var(_) => "var",
+        };
+        write!(f, "{}", s)
+    }
+}
+
 // Formatting functions used in eager and lazy code for renaming grouped columns
 pub fn fmt_groupby_column(name: &str, method: GroupByMethod) -> String {
     use GroupByMethod::*;
@@ -1123,19 +1146,6 @@ mod test {
         );
     }
 
-    #[test]
-    #[cfg_attr(miri, ignore)]
-    fn test_groupby_apply() {
-        let df = df! {
-            "a" => [1, 1, 2, 2, 2],
-            "b" => [1, 2, 3, 4, 5]
-        }
-        .unwrap();
-
-        let out = df.groupby(["a"]).unwrap().apply(Ok).unwrap();
-        assert!(out.sort(["b"], false).unwrap().frame_equal(&df));
-    }
-
     #[test]
     #[cfg_attr(miri, ignore)]
     fn test_groupby_threaded() {
