@@ -3,11 +3,10 @@ use std::borrow::Cow;
 
 use polars_arrow::prelude::QuantileInterpolOptions;
 
-use super::private;
-use super::IntoSeries;
-use super::SeriesTrait;
+use super::{private, IntoSeries, SeriesTrait};
 use crate::chunked_array::comparison::*;
-use crate::chunked_array::{ops::explode::ExplodeByOffsets, AsSinglePtr};
+use crate::chunked_array::ops::explode::ExplodeByOffsets;
+use crate::chunked_array::AsSinglePtr;
 use crate::fmt::FmtList;
 use crate::frame::groupby::*;
 use crate::prelude::*;
@@ -84,8 +83,7 @@ impl SeriesTrait for SeriesWrap<ListChunked> {
 
     fn append(&mut self, other: &Series) -> Result<()> {
         if self.0.dtype() == other.dtype() {
-            self.0.append(other.as_ref().as_ref());
-            Ok(())
+            self.0.append(other.as_ref().as_ref())
         } else {
             Err(PolarsError::SchemaMisMatch(
                 "cannot append Series; data types don't match".into(),
@@ -94,8 +92,7 @@ impl SeriesTrait for SeriesWrap<ListChunked> {
     }
     fn extend(&mut self, other: &Series) -> Result<()> {
         if self.0.dtype() == other.dtype() {
-            self.0.extend(other.as_ref().as_ref());
-            Ok(())
+            self.0.extend(other.as_ref().as_ref())
         } else {
             Err(PolarsError::SchemaMisMatch(
                 "cannot extend Series; data types don't match".into(),
