@@ -191,7 +191,7 @@ impl Series {
         self
     }
 
-    /// Shrink the capacity of this array to fit it's length.
+    /// Shrink the capacity of this array to fit its length.
     pub fn shrink_to_fit(&mut self) {
         self._get_inner_mut().shrink_to_fit()
     }
@@ -673,14 +673,18 @@ impl Series {
     pub fn strict_cast(&self, data_type: &DataType) -> Result<Series> {
         let s = self.cast(data_type)?;
         if self.null_count() != s.null_count() {
+            let failure_mask = !self.is_null() & s.is_null();
+            let failures = self.filter_threaded(&failure_mask, false)?.unique()?;
             Err(PolarsError::ComputeError(
                 format!(
-                    "strict conversion of cast from {:?} to {:?} failed. consider non-strict cast.\n
-                    If you were trying to cast Utf8 to Date,Time,Datetime, consider using `strptime`",
+                    "Strict conversion from {:?} to {:?} failed for values {}. \
+                    If you were trying to cast Utf8 to Date, Time, or Datetime, \
+                    consider using `strptime`.",
                     self.dtype(),
-                    data_type
+                    data_type,
+                    failures.fmt_list(),
                 )
-                    .into(),
+                .into(),
             ))
         } else {
             Ok(s)
@@ -846,12 +850,16 @@ impl Series {
     }
 
     pub fn mean_as_series(&self) -> Series {
-        let val = [self.mean()];
-        let s = Series::new(self.name(), val);
-        if !self.dtype().is_numeric() {
-            Series::full_null(self.name(), 1, self.dtype())
-        } else {
-            s
+        match self.dtype() {
+            DataType::Float32 => {
+                let val = &[self.mean().map(|m| m as f32)];
+                Series::new(self.name(), val)
+            }
+            dt if dt.is_numeric() => {
+                let val = &[self.mean()];
+                Series::new(self.name(), val)
+            }
+            _ => return Series::full_null(self.name(), 1, self.dtype()),
         }
     }
 
