@@ -3,13 +3,11 @@ pub(crate) mod series;
 use std::borrow::Cow;
 use std::ops::{Deref, DerefMut};
 
-pub use arrow;
 use arrow::bitmap::Bitmap;
-pub use polars_arrow::utils::TrustMyLength;
-pub use polars_arrow::utils::*;
-pub use rayon;
+pub use polars_arrow::utils::{TrustMyLength, *};
 use rayon::prelude::*;
 pub use series::*;
+pub use {arrow, rayon};
 
 #[cfg(feature = "private")]
 pub use crate::chunked_array::ops::sort::argsort_no_nulls;
@@ -112,8 +110,9 @@ where
 }
 
 // prefer this one over split_ca, as this can push the null_count into the thread pool
+// returns an `(offset, length)` tuple
 #[doc(hidden)]
-pub fn split_offsets(len: usize, n: usize) -> Vec<(usize, usize)> {
+pub fn _split_offsets(len: usize, n: usize) -> Vec<(usize, usize)> {
     if n == 1 {
         vec![(0, len)]
     } else {
@@ -158,10 +157,13 @@ fn flatten_df(df: &DataFrame) -> impl Iterator<Item = DataFrame> + '_ {
 
 #[cfg(feature = "private")]
 #[doc(hidden)]
-pub fn split_df(df: &DataFrame, n: usize) -> Result<Vec<DataFrame>> {
+/// Split a [`DataFrame`] into `n` parts. We take a `&mut` to be able to repartition/align chunks.
+pub fn split_df(df: &mut DataFrame, n: usize) -> Result<Vec<DataFrame>> {
     if n == 0 {
         return Ok(vec![df.clone()]);
     }
+    // make sure that chunks are aligned.
+    df.rechunk();
     let total_len = df.height();
     let chunk_size = total_len / n;
 
@@ -466,19 +468,18 @@ pub fn get_time_units(tu_l: &TimeUnit, tu_r: &TimeUnit) -> TimeUnit {
 
 /// Given two datatypes, determine the supertype that both types can safely be cast to
 #[cfg(feature = "private")]
-pub fn get_supertype(l: &DataType, r: &DataType) -> Result<DataType> {
-    match _get_supertype(l, r) {
+pub fn try_get_supertype(l: &DataType, r: &DataType) -> Result<DataType> {
+    match get_supertype(l, r) {
         Some(dt) => Ok(dt),
-        None => _get_supertype(r, l).ok_or_else(|| {
-            PolarsError::ComputeError(
-                format!("Failed to determine supertype of {:?} and {:?}", l, r).into(),
-            )
-        }),
+        None => Err(PolarsError::ComputeError(
+            format!("Failed to determine supertype of {:?} and {:?}", l, r).into(),
+        )),
     }
 }
 
 /// Given two datatypes, determine the supertype that both types can safely be cast to
-fn _get_supertype(l: &DataType, r: &DataType) -> Option<DataType> {
+#[cfg(feature = "private")]
+pub fn get_supertype(l: &DataType, r: &DataType) -> Option<DataType> {
     fn inner(l: &DataType, r: &DataType) -> Option<DataType> {
         use DataType::*;
         if l == r {
@@ -710,12 +711,12 @@ fn _get_supertype(l: &DataType, r: &DataType) -> Option<DataType> {
                 Some(Datetime(tu, tz_r.clone()))
             }
             (List(inner_left), List(inner_right)) => {
-                let st = _get_supertype(inner_left, inner_right)?;
+                let st = get_supertype(inner_left, inner_right)?;
                 Some(DataType::List(Box::new(st)))
             }
             // todo! check if can be removed
             (List(inner), other) | (other, List(inner)) => {
-                let st = _get_supertype(inner, other)?;
+                let st = get_supertype(inner, other)?;
                 Some(DataType::List(Box::new(st)))
             }
             (_, Unknown) => Some(Unknown),
@@ -808,7 +809,7 @@ where
     F: Fn(Series) -> Result<Series> + Send + Sync,
 {
     let n_threads = n_threads.unwrap_or_else(|| POOL.current_num_threads());
-    let splits = split_offsets(s.len(), n_threads);
+    let splits = _split_offsets(s.len(), n_threads);
 
     let chunks = POOL.install(|| {
         splits
