@@ -12,21 +12,9 @@ pub(crate) struct GroupByDynamicExec {
     pub(crate) slice: Option<(i64, usize)>,
 }
 
-impl Executor for GroupByDynamicExec {
-    #[cfg(not(feature = "dynamic_groupby"))]
-    fn execute(&mut self, _state: &mut ExecutionState) -> Result<DataFrame> {
-        panic!("activate feature dynamic_groupby")
-    }
-
+impl GroupByDynamicExec {
     #[cfg(feature = "dynamic_groupby")]
-    fn execute(&mut self, state: &mut ExecutionState) -> Result<DataFrame> {
-        #[cfg(debug_assertions)]
-        {
-            if state.verbose() {
-                println!("run GroupbyDynamicExec")
-            }
-        }
-        let mut df = self.input.execute(state)?;
+    fn execute_impl(&mut self, state: &mut ExecutionState, mut df: DataFrame) -> Result<DataFrame> {
         df.as_single_chunk_par();
         state.set_schema(self.input_schema.clone());
 
@@ -63,21 +51,21 @@ impl Executor for GroupByDynamicExec {
         }
 
         let agg_columns = POOL.install(|| {
-                self.aggs
-                    .par_iter()
-                    .map(|expr| {
-                        let agg = expr.evaluate_on_groups(&df, groups, state)?.finalize();
-                        if agg.len() != groups.len() {
-                            return Err(PolarsError::ComputeError(
-                                format!("returned aggregation is a different length: {} than the group lengths: {}",
-                                        agg.len(),
-                                        groups.len()).into()
-                            ))
-                        }
-                        Ok(agg)
-                    })
-                    .collect::<Result<Vec<_>>>()
-            })?;
+            self.aggs
+                .par_iter()
+                .map(|expr| {
+                    let agg = expr.evaluate_on_groups(&df, groups, state)?.finalize();
+                    if agg.len() != groups.len() {
+                        return Err(PolarsError::ComputeError(
+                            format!("returned aggregation is a different length: {} than the group lengths: {}",
+                                    agg.len(),
+                                    groups.len()).into()
+                        ))
+                    }
+                    Ok(agg)
+                })
+                .collect::<Result<Vec<_>>>()
+        })?;
 
         state.clear_schema_cache();
         let mut columns = Vec::with_capacity(agg_columns.len() + 1 + keys.len());
@@ -88,3 +76,40 @@ impl Executor for GroupByDynamicExec {
         DataFrame::new(columns)
     }
 }
+
+impl Executor for GroupByDynamicExec {
+    #[cfg(not(feature = "dynamic_groupby"))]
+    fn execute(&mut self, _state: &mut ExecutionState) -> Result<DataFrame> {
+        panic!("activate feature dynamic_groupby")
+    }
+
+    #[cfg(feature = "dynamic_groupby")]
+    fn execute(&mut self, state: &mut ExecutionState) -> Result<DataFrame> {
+        #[cfg(debug_assertions)]
+        {
+            if state.verbose() {
+                println!("run GroupbyDynamicExec")
+            }
+        }
+        let df = self.input.execute(state)?;
+
+        let profile_name = if state.has_node_timer() {
+            let by = self
+                .keys
+                .iter()
+                .map(|s| Ok(s.to_field(&self.input_schema)?.name))
+                .collect::<Result<Vec<_>>>()?;
+            let name = column_delimited("groupby_dynamic".to_string(), &by);
+            Cow::Owned(name)
+        } else {
+            Cow::Borrowed("")
+        };
+
+        if state.has_node_timer() {
+            let new_state = state.clone();
+            new_state.record(|| self.execute_impl(state, df), profile_name)
+        } else {
+            self.execute_impl(state, df)
+        }
+    }
+}
