@@ -60,8 +60,25 @@ impl Executor for ParquetExec {
                 .map(|ae| ae.as_expression().unwrap().clone()),
             slice: (0, self.options.n_rows),
         };
-        state
-            .file_cache
-            .read(finger_print, self.options.file_counter, &mut || self.read())
+
+        let profile_name = if state.has_node_timer() {
+            let mut ids = vec![self.path.to_string_lossy().to_string()];
+            if self.predicate.is_some() {
+                ids.push("predicate".to_string())
+            }
+            let name = column_delimited("parquet".to_string(), &ids);
+            Cow::Owned(name)
+        } else {
+            Cow::Borrowed("")
+        };
+
+        state.record(
+            || {
+                state
+                    .file_cache
+                    .read(finger_print, self.options.file_counter, &mut || self.read())
+            },
+            profile_name,
+        )
     }
 }
