@@ -16,6 +16,7 @@ mod ternary;
 mod window;
 
 use std::borrow::Cow;
+use std::fmt::{Display, Formatter};
 
 pub(crate) use aggregation::*;
 pub(crate) use alias::*;
@@ -593,6 +594,15 @@ pub trait PhysicalExpr: Send + Sync {
     }
 }
 
+impl Display for &dyn PhysicalExpr {
+    fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
+        match self.as_expression() {
+            None => Ok(()),
+            Some(e) => write!(f, "{}", e),
+        }
+    }
+}
+
 /// Wrapper struct that allow us to use a PhysicalExpr in polars-io.
 ///
 /// This is used to filter rows during the scan of file.
