@@ -257,7 +257,9 @@ def _assert_series_inner(
         else:
             # apply check with tolerance, but only to the known-unequal matches
             left, right = left.filter(unequal), right.filter(unequal)
-            if ((left - right).abs() > (atol + rtol * right.abs())).sum() != 0:
+            if (((left - right).abs() > (atol + rtol * right.abs())).sum() != 0) or (
+                (left.is_null() != right.is_null()).any()
+            ):
                 raise_assert_detail(
                     obj, "Value mismatch", left=list(left), right=list(right)
                 )
@@ -407,7 +409,7 @@ if HYPOTHESIS_INSTALLED:
 
         name: str
         dtype: PolarsDataType | None = None
-        strategy: SearchStrategy[pli.Series] | None = None
+        strategy: SearchStrategy[pli.Series | int] | None = None
         null_probability: float | None = None
         unique: bool = False
 
