@@ -1,6 +1,7 @@
 from __future__ import annotations
 
 import io
+import sys
 from datetime import date, datetime, time, timedelta
 from typing import TYPE_CHECKING, no_type_check
 
@@ -8,7 +9,11 @@ import numpy as np
 import pandas as pd
 import pyarrow as pa
 import pytest
-import pytz
+
+if sys.version_info >= (3, 9):
+    import zoneinfo
+else:
+    from backports import zoneinfo
 
 import polars as pl
 from polars.datatypes import DTYPE_TEMPORAL_UNITS
@@ -372,12 +377,12 @@ def test_date_range() -> None:
     ]
 
     result = pl.date_range(
-        datetime(2022, 1, 1), datetime(2022, 1, 1, 0, 1), "987654321ns"
+        datetime(2022, 1, 1), datetime(2022, 1, 1, 0, 1), "987456321ns"
     )
     assert len(result) == 61
     assert result.dtype.tu == "ns"  # type: ignore[attr-defined]
     assert result.dt.second()[-1] == 59
-    assert result.dt.nanosecond()[-1] == 259259260
+    assert result.cast(pl.Utf8)[-1] == "2022-01-01 00:00:59.247379260"
 
 
 def test_date_comp() -> None:
@@ -660,8 +665,8 @@ def test_read_utc_times_parquet() -> None:
     df.to_parquet(f)
     f.seek(0)
     df_in = pl.read_parquet(f)
-    tz = pytz.timezone("UTC")
-    assert df_in["Timestamp"][0] == tz.localize(datetime(2022, 1, 1, 0, 0))
+    tz = zoneinfo.ZoneInfo("UTC")
+    assert df_in["Timestamp"][0] == datetime(2022, 1, 1, 0, 0).astimezone(tz)
 
 
 def test_epoch() -> None:
@@ -710,6 +715,31 @@ def test_strptime_dates_datetimes() -> None:
     ]
 
 
+def test_strptime_precision() -> None:
+    s = pl.Series(
+        "date", ["2022-09-12 21:54:36.789321456", "2022-09-13 12:34:56.987456321"]
+    )
+    ds = s.str.strptime(pl.Datetime)
+    assert ds.cast(pl.Date) != None  # noqa: E711  (note: *deliberately* testing "!=")
+    assert getattr(ds.dtype, "tu", None) == "us"
+
+    time_units: list[TimeUnit] = ["ms", "us", "ns"]
+    suffixes = ["%.3f", "%.6f", "%.9f"]
+    test_data = zip(
+        time_units,
+        suffixes,
+        (
+            [789000000, 987000000],
+            [789321000, 987456000],
+            [789321456, 987456321],
+        ),
+    )
+    for precision, suffix, expected_values in test_data:
+        ds = s.str.strptime(pl.Datetime(precision), f"%Y-%m-%d %H:%M:%S{suffix}")
+        assert getattr(ds.dtype, "tu", None) == precision
+        assert ds.dt.nanosecond().to_list() == expected_values
+
+
 def test_asof_join_tolerance_grouper() -> None:
     from datetime import date
 
@@ -869,7 +899,6 @@ def test_asof_join() -> None:
             "bid": [720.5, 51.95, 51.97, 51.99, 720.50, 97.99, 720.50, 52.01],
         }
     )
-
     dates = [
         "2016-05-25 13:30:00.023",
         "2016-05-25 13:30:00.038",
@@ -891,10 +920,22 @@ def test_asof_join() -> None:
             "bid": [51.95, 51.95, 720.77, 720.92, 98.0],
         }
     )
-
+    assert trades.schema == {
+        "dates": pl.Datetime("ms"),
+        "ticker": pl.Utf8,
+        "bid": pl.Float64,
+    }
     out = trades.join_asof(quotes, on="dates", strategy="backward")
+
+    assert out.schema == {
+        "bid": pl.Float64,
+        "bid_right": pl.Float64,
+        "dates": pl.Datetime("ms"),
+        "ticker": pl.Utf8,
+        "ticker_right": pl.Utf8,
+    }
     assert out.columns == ["dates", "ticker", "bid", "ticker_right", "bid_right"]
-    assert (out["dates"].cast(int) / 1000).to_list() == [
+    assert (out["dates"].cast(int)).to_list() == [
         1464183000023,
         1464183000038,
         1464183000048,
@@ -1369,7 +1410,7 @@ def test_weekday() -> None:
 
 
 def test_from_dict_tu_consistency() -> None:
-    tz = pytz.timezone("PRC")
+    tz = zoneinfo.ZoneInfo("PRC")
     dt = datetime(2020, 8, 1, 12, 0, 0, tzinfo=tz)
     from_dict = pl.from_dict({"dt": [dt]})
     from_dicts = pl.from_dicts([{"dt": dt}])
