@@ -1,8 +1,8 @@
 from __future__ import annotations
 
 import math
-from datetime import date, datetime
-from typing import Any, cast
+from datetime import date, datetime, time
+from typing import TYPE_CHECKING, Any, cast
 
 import numpy as np
 import pandas as pd
@@ -10,9 +10,12 @@ import pyarrow as pa
 import pytest
 
 import polars as pl
-from polars.datatypes import Date, Datetime, Float64, Int32, Int64, UInt32, UInt64
+from polars.datatypes import Date, Datetime, Float64, Int32, Int64, Time, UInt32, UInt64
 from polars.testing import assert_series_equal, verify_series_and_expr_api
 
+if TYPE_CHECKING:
+    from polars.internals.type_aliases import TimeUnit
+
 
 def test_cum_agg() -> None:
     # confirm that known series give expected results
@@ -328,6 +331,10 @@ def test_cast() -> None:
     assert a.cast(pl.Datetime).dtype == pl.Datetime
     assert a.cast(pl.Date).dtype == pl.Date
 
+    # display failed values, GH#4706
+    with pytest.raises(pl.ComputeError, match="foobar"):
+        pl.Series(["1", "2", "3", "4", "foobar"]).cast(int)
+
 
 def test_to_python() -> None:
     a = pl.Series("a", range(20))
@@ -1381,10 +1388,12 @@ def test_peak_max_peak_min() -> None:
 
 def test_shrink_to_fit() -> None:
     s = pl.Series("a", [4, 1, 3, 2, 5])
-    assert s.shrink_to_fit(in_place=True) is None
+    sf = s.shrink_to_fit(in_place=True)
+    assert sf is s
 
     s = pl.Series("a", [4, 1, 3, 2, 5])
-    assert isinstance(s.shrink_to_fit(in_place=False), pl.Series)
+    sf = s.shrink_to_fit(in_place=False)
+    assert s is not sf
 
 
 def test_str_concat() -> None:
@@ -1481,7 +1490,6 @@ def test_str_strptime() -> None:
     verify_series_and_expr_api(
         s, expected, "str.strptime", pl.Datetime, "%Y-%m-%d %H:%M:%S"
     )
-
     s = pl.Series(["00:00:00", "03:20:10"])
     expected = pl.Series([0, 12010000000000], dtype=pl.Time)
     verify_series_and_expr_api(s, expected, "str.strptime", pl.Time, "%H:%M:%S")
@@ -1513,14 +1521,16 @@ def test_dt_year_month_week_day_ordinal_day() -> None:
 
 
 def test_dt_datetimes() -> None:
-    s = pl.Series(["2020-01-01 00:00:00", "2020-02-02 03:20:10"])
-    s = s.str.strptime(pl.Datetime, fmt="%Y-%m-%d %H:%M:%S")
+    s = pl.Series(["2020-01-01 00:00:00.000000000", "2020-02-02 03:20:10.987654321"])
+    s = s.str.strptime(pl.Datetime, fmt="%Y-%m-%d %H:%M:%S.%9f")
 
     # hours, minutes, seconds and nanoseconds
     verify_series_and_expr_api(s, pl.Series("", [0, 3], dtype=UInt32), "dt.hour")
     verify_series_and_expr_api(s, pl.Series("", [0, 20], dtype=UInt32), "dt.minute")
     verify_series_and_expr_api(s, pl.Series("", [0, 10], dtype=UInt32), "dt.second")
-    verify_series_and_expr_api(s, pl.Series("", [0, 0], dtype=UInt32), "dt.nanosecond")
+    verify_series_and_expr_api(
+        s, pl.Series("", [0, 987654321], dtype=UInt32), "dt.nanosecond"
+    )
 
     # epoch methods
     verify_series_and_expr_api(
@@ -1538,6 +1548,36 @@ def test_dt_datetimes() -> None:
         "dt.epoch",
         tu="ms",
     )
+    # fractional seconds
+    assert pl.Series("", [0.0, 10.987654321], dtype=Float64) == s.dt.second(
+        fractional=True
+    )
+
+
+@pytest.mark.parametrize("unit", ["ns", "us", "ms"])
+def test_cast_datetime_to_time(unit: TimeUnit) -> None:
+    a = pl.Series(
+        "a",
+        [
+            datetime(2022, 9, 7, 0, 0),
+            datetime(2022, 9, 6, 12, 0),
+            datetime(2022, 9, 7, 23, 59, 59),
+            datetime(2022, 9, 7, 23, 59, 59, 201),
+        ],
+        dtype=Datetime(unit),
+    )
+    if unit == "ms":
+        # NOTE: microseconds are lost for `unit=ms`
+        expected_values = [time(0, 0), time(12, 0), time(23, 59, 59), time(23, 59, 59)]
+    else:
+        expected_values = [
+            time(0, 0),
+            time(12, 0),
+            time(23, 59, 59),
+            time(23, 59, 59, 201),
+        ]
+    expected = pl.Series("a", expected_values)
+    assert_series_equal(a.cast(Time), expected)
 
 
 def test_reshape() -> None:
@@ -1730,24 +1770,27 @@ def test_ewm_mean_min_periods() -> None:
     assert ewm_mean.to_list() == [
         1.0,
         1.0,
-        1.6666666666666667,
-        1.6666666666666667,
+        1.6666666666666665,
+        1.6666666666666665,
         2.4285714285714284,
     ]
     ewm_mean = series.ewm_mean(alpha=0.5, min_periods=2)
     assert ewm_mean.to_list() == [
         None,
         None,
-        1.6666666666666667,
-        1.6666666666666667,
+        1.6666666666666665,
+        1.6666666666666665,
         2.4285714285714284,
     ]
 
 
 def test_ewm_std_var() -> None:
-    a = pl.Series("a", [2, 5, 3])
+    series = pl.Series("a", [2, 5, 3])
 
-    assert (a.ewm_std(alpha=0.5) ** 2).to_list() == a.ewm_var(alpha=0.5).to_list()
+    var = series.ewm_var(alpha=0.5)
+    std = series.ewm_std(alpha=0.5)
+
+    assert np.allclose(var, std**2, rtol=1e-16)
 
 
 def test_extend_constant() -> None:
@@ -1920,8 +1963,7 @@ def test_clip() -> None:
 
 def test_mutable_borrowed_append_3915() -> None:
     s = pl.Series("s", [1, 2, 3])
-    s.append(s)
-    assert s.to_list() == [1, 2, 3, 1, 2, 3]
+    assert s.append(s).to_list() == [1, 2, 3, 1, 2, 3]
 
 
 def test_set_at_idx() -> None:
